phpinfo()

# PHP Version 4.4.4

System | Linux localhost Tue Nov i386
Configure Command | './configure' '--with-config-file-path=/usr/local/etc/' '--with-apxs' '--with-mod_charset' '--with-exec-dir=/users' '--enable-safe-mode' '--enable-magic-quotes' '--with-zlib' '--enable-bcmath' '--with-bz7' '--enable-calendar' '--with-crack' '--with-curl' '--enable-dba' '--enable-dbase' '--with-dom' '--with-dom-xslt' '--enable-exif' '--enable-ftp' '--with-gd' '--with-jpeg-dir' '--with-png-dir' '--with-zlib-dir' '--with-xpm-dir' '--with-freetype-dir' '--with-ttf' '--enable-gd-native-ttf' '--with-gettext' '--with-iconv' '--with-ldap' '--enable-mbstring=all' '--enable-mbregex' '--with-mcal' '--with-mcrypt' '--with-mhash' '--with-mime-magic' '--with-ming' '--with-mysql=/usr/local' '--with-pgsql' '--with-pspell' '--with-recode' '--with-regex=system' '--enable-sysvmsg' '--enable-sysvsem' '--enable-sysvshm' '--enable-wddx' '--with-zip' '--enable-versioning' '--enable-memory-limit' '--enable-zend-multibyte' '--with-openssl' '--with-xslt-sablot'
Server API | Apache
Virtual Directory Support | disabled
Configuration File (php.ini) Path | /usr/local/etc/php.ini
PHP API | 20020918
PHP Extension | 20020429
Zend Extension | 20050606
Debug Build | no
Zend Memory Manager | enabled
Thread Safety | disabled
Registered PHP Streams | php, http, ftp, https, ftps, compress.zlib

This program makes use of the Zend Scripting Language Engine: Zend Engine v1.3.0, Copyright (c) 1998-2004 Zend Technologies with the ionCube PHP Loader v3.1.23, Copyright (c) 2002-2006, by ionCube Ltd., and with Zend Extension Manager v1.0.9, Copyright (c) 2003-2005, by Zend Technologies with Zend Optimizer v2.6.0, Copyright (c) 1998-2005, by Zend Technologies

# Configuration

## PHP Core

Directive | Local Value | Master Value
--- | --- | ---
allow_call_time_pass_reference | On | On
allow_url_fopen | On | On
always_populate_raw_post_data | Off | Off
arg_separator.input | & | &
arg_separator.output | & | &
asp_tags | On | On
auto_append_file | no value | no value
auto_prepend_file | no value | no value
browscap | no value | no value
default_charset | no value | no value
default_mimetype | text/html | text/html
define_syslog_variables | Off | Off
disable_classes | no value | no value
disable_functions | mb_send_mail,error_log,symlink | mb_send_mail,error_log,symlink
display_errors | On | On
display_startup_errors | Off | Off
doc_root | no value | no value
docref_ext | no value | no value
docref_root | no value | no value
enable_dl | On | On
error_append_string | no value | no value
error_log | no value | no value
error_prepend_string | no value | no value
error_reporting | 0 | 0
expose_php | Off | Off
extension_dir | ./ | ./
file_uploads | On | On
gpc_order | GPC | GPC
highlight.bg | #FFFFFF | #FFFFFF
highlight.comment | #FF8000 | #FF8000
highlight.default | #0000BB | #0000BB
highlight.html | #000000 | #000000
highlight.keyword | #007700 | #007700
highlight.string | #DD0000 | #DD0000
html_errors | On | On
ignore_repeated_errors | Off | Off
ignore_repeated_source | Off | Off
ignore_user_abort | Off | Off
implicit_flush | Off | Off
include_path | .:/usr/local/lib/php:/usr/local/lib/php/lib | .:/usr/local/lib/php:/usr/local/lib/php/lib
log_errors | On | On
log_errors_max_len | 1024 | 1024
magic_quotes_gpc | On | On
magic_quotes_runtime | Off | Off
magic_quotes_sybase | Off | Off
max_execution_time | 300 | 300
max_input_time | 120 | 120
memory_limit | 16M | 16M
open_basedir | no value | no value
output_buffering | no value | no value
output_handler | no value | no value
post_max_size | 8M | 8M
precision | 12 | 12
register_argc_argv | On | On
register_globals | On | On
report_memleaks | On | On
safe_mode | Off | Off
safe_mode_exec_dir | /users/bin/ | /users/bin/
safe_mode_gid | Off | Off
safe_mode_include_dir | .:/usr/local/lib/php:/usr/local/lib/php/lib | .:/usr/local/lib/php:/usr/local/lib/php/lib
sendmail_from | me@localhost.com | me@localhost.com
sendmail_path | /usr/sbin/sendmail -t -i | /usr/sbin/sendmail -t -i
serialize_precision | 100 | 100
short_open_tag | On | On
SMTP | localhost | localhost
smtp_port | 25 | 25
sql.safe_mode | Off | Off
track_errors | On | On
unserialize_callback_func | no value | no value
upload_max_filesize | 8M | 8M
upload_tmp_dir | /tmp | /tmp
user_dir | no value | no value
variables_order | EGPCS | EGPCS
xmlrpc_error_number | 0 | 0
xmlrpc_errors | Off | Off
y2k_compliance | On | On

## Zend Optimizer

Optimization Pass 1 | enabled
Optimization Pass 2 | enabled
Optimization Pass 3 | enabled
Optimization Pass 4 | enabled
Optimization Pass 9 | disabled
Zend Loader | enabled
License Path | no value

## apache

APACHE_INCLUDE | no value
APACHE_TARGET | no value
Apache Version | Apache PHP/4.4.4
Apache Release | 10337100
Apache API Version | 19990320
Hostname:Port | localhost:80
User/Group | nobody(65534)/65533
Max Requests | Per Child: 20 - Keep Alive: on - Max Per Connection: 150
Timeouts | Connection: 100 - Keep-Alive: 0
Server Root | /var/www
Loaded Modules | mod_layout, mod_limitipconn, mod_evasive, mod_tsunami, mod_php4, mod_setenvif, mod_so, mod_unique_id, mod_usertrack, mod_headers, mod_expires, mod_cern_meta, mod_proxy, mod_digest, mod_auth_db, mod_auth_anon, mod_auth, mod_access, mod_rewrite, mod_alias, mod_userdir, mod_speling, mod_actions, mod_imap, mod_asis, mod_cgi, mod_dir, mod_autoindex, mod_include, mod_info, mod_status, mod_negotiation, mod_mime, mod_mime_magic, mod_log_config, mod_env, mod_vhost_alias, mod_mmap_static, mod_charset, mod_throttle, mod_bandwidth, http_core

Directive | Local Value | Master Value
--- | --- | ---
child_terminate | 0 | 0
engine | 1 | 1
last_modified | 0 | 0
xbithack | 0 | 0

## Apache Environment

Variable | Value
--- | ---
CHARSET | koi8-r
CHARSET_DETERMINED_BY | UserAgent
CHARSET_HTTP_METHOD | http://
CHARSET_REFERER | -
CHARSET_SERVER_NAME | localhost:80
CHARSET_SERVER_PORT | 80
DOCUMENT_ROOT | /var/www/
HTTP_ACCEPT | text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8
HTTP_ACCEPT_CHARSET | ISO-8859-1,utf-8;q=0.7,*;q=0.3
HTTP_ACCEPT_ENCODING | gzip,deflate,sdch
HTTP_ACCEPT_LANGUAGE | it-IT,it;q=0.8,en-US;q=0.6,en;q=0.4
HTTP_CONNECTION | keep-alive
HTTP_HOST | localhost
PATH | /etc:/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin
SCRIPT_FILENAME | /var/www/phpinfo.php
SERVER_SOFTWARE | Apache (Unix) PHP/4.4.4
GATEWAY_INTERFACE | CGI/1.1
SERVER_PROTOCOL | HTTP/1.1
REQUEST_METHOD | GET
QUERY_STRING | no value

## bcmath

BCMath support | enabled

## calendar

Calendar support | enabled

## crack

crack support | enabled
--- | ---

Directive | Local Value | Master Value
--- | --- | ---
crack.default_dictionary | no value | no value

## ctype

ctype functions | enabled

## curl

CURL support | enabled
CURL Information | libcurl/7.10.7 OpenSSL/0.9.7d zlib/1.1.4

## dba

DBA support | enabled
Supported handlers | cdb cdb_make inifile flatfile

## domxml

DOM/XML | enabled
DOM/XML API Version | 20020815
libxml Version | 20507
HTML Support | enabled
XPath Support | enabled
XPointer Support | enabled
DOM/XSLT | enabled
libxslt Version | 1.0.30
libxslt compiled against libxml Version | 2.5.7

## exif

EXIF Support | enabled
EXIF Version | 1.4 $Id: exif.c,v 1.118.2.37.2.4 2006/01/01 13:46:52 sniper Exp $
Supported EXIF Version | 0220
Supported filetypes | JPEG,TIFF

## ftp

FTP support | enabled

## gd

GD Support | enabled
GD Version | bundled (2.0.28 compatible)
FreeType Support | enabled
FreeType Linkage | with freetype
GIF Read Support | enabled
GIF Create Support | enabled
JPG Support | enabled
PNG Support | enabled
WBMP Support | enabled
XBM Support | enabled

## gettext

GetText Support | enabled

## iconv

iconv support | enabled
iconv implementation | unknown
iconv library version | unknown

Directive | Local Value | Master Value
--- | --- | ---
iconv.input_encoding | ISO-8859-1 | ISO-8859-1
iconv.internal_encoding | ISO-8859-1 | ISO-8859-1
iconv.output_encoding | ISO-8859-1 | ISO-8859-1

## ldap

LDAP Support | enabled
RCS Version | $Id: ldap.c,v 1.130.2.13.2.1 2006/01/01 13:46:54 sniper Exp $
Total Links | 0/unlimited
API Version | 2004
Vendor Name | OpenLDAP
Vendor Version | 20120

## mbstring

Multibyte Support | enabled
Japanese support | enabled
Simplified chinese support | enabled
Traditional chinese support | enabled
Korean support | enabled
Russian support | enabled
Multibyte (japanese) regex support | enabled

mbstring extension makes use of "streamable kanji code filter and converter", which is distributed under the GNU Lesser General Public License version 2.1.

Directive | Local Value | Master Value
--- | --- | ---
mbstring.detect_order | no value | no value
mbstring.encoding_translation | Off | Off
mbstring.func_overload | 0 | 0
mbstring.http_input | pass | pass
mbstring.http_output | pass | pass
mbstring.internal_encoding | no value | no value
mbstring.language | neutral | neutral
mbstring.script_encoding | no value | no value
mbstring.substitute_character | no value | no value

## mcal

MCAL Support | enabled
MCAL Version | 0.6 - 20000121

## mcrypt

mcrypt support | enabled
--- | ---
version | >= 2.4.x
Supported ciphers | cast-128 gost rijndael-128 twofish arcfour cast-256 loki97 rijndael-192 saferplus wake blowfish-compat des rijndael-256 serpent xtea blowfish enigma rc2 tripledes
Supported modes | cbc cfb ctr ecb ncfb nofb ofb stream

Directive | Local Value | Master Value
--- | --- | ---
mcrypt.algorithms_dir | no value | no value
mcrypt.modes_dir | no value | no value

## mhash

MHASH support | Enabled
MHASH API Version | 20020524

## mime_magic

mime_magic support | enabled
--- | ---

Directive | Local Value | Master Value
--- | --- | ---
mime_magic.magicfile | /usr/share/misc/magic.mime | /usr/share/misc/magic.mime

## ming

Ming SWF output library | enabled
Version | 0.2a

## mysql

MySQL Support | enabled
--- | ---
Active Persistent Links | 0
Active Links | 0
Client API version | 4.1.22
MYSQL_MODULE_TYPE | external
MYSQL_SOCKET | /tmp/mysql.sock
MYSQL_INCLUDE | -I/usr/local/include/mysql
MYSQL_LIBS | -L/usr/local/lib/mysql -lmysqlclient

Directive | Local Value | Master Value
--- | --- | ---
mysql.allow_persistent | On | On
mysql.connect_timeout | -1 | -1
mysql.default_host | localhost | localhost
mysql.default_password | no value | no value
mysql.default_port | no value | no value
mysql.default_socket | no value | no value
mysql.default_user | no value | no value
mysql.max_links | Unlimited | Unlimited
mysql.max_persistent | Unlimited | Unlimited
mysql.trace_mode | Off | Off

## openssl

OpenSSL support | enabled
OpenSSL Version | OpenSSL 0.9.7d-p1 17 Mar 2004

## overload

User-Space Object Overloading Support | enabled

## pcre

PCRE (Perl Compatible Regular Expressions) Support | enabled
PCRE Library Version | 6.6 06-Feb-2006

## pgsql

PostgreSQL Support | enabled
--- | ---
PostgreSQL(libpq) Version | 7.3.3
Multibyte character support | enabled
SSL support | enabled
Active Persistent Links | 0
Active Links | 0

Directive | Local Value | Master Value
--- | --- | ---
pgsql.allow_persistent | On | On
pgsql.auto_reset_persistent | Off | Off
pgsql.ignore_notice | Off | Off
pgsql.log_notice | Off | Off
pgsql.max_links | Unlimited | Unlimited
pgsql.max_persistent | Unlimited | Unlimited

## posix

Revision | $Revision: 1.51.2.4.2.1 $

## pspell

PSpell Support | enabled

## recode

Recode Support | enabled
Revision | $Revision: 1.29.2.1.8.1 $

## session

Session Support | enabled
Registered save handlers | files user

Directive | Local Value | Master Value
--- | --- | ---
session.auto_start | Off | Off
session.bug_compat_42 | On | On
session.bug_compat_warn | On | On
session.cache_expire | 180 | 180
session.cache_limiter | nocache | nocache
session.cookie_domain | no value | no value
session.cookie_lifetime | 0 | 0
session.cookie_path | / | /
session.cookie_secure | Off | Off
session.entropy_file | no value | no value
session.entropy_length | 0 | 0
session.gc_divisor | 100 | 100
session.gc_maxlifetime | 1440 | 1440
session.gc_probability | 1 | 1
session.name | PHPSESSID | PHPSESSID
session.referer_check | no value | no value
session.save_handler | files | files
session.save_path | /tmp/php | /tmp/php
session.serialize_handler | php | php
session.use_cookies | On | On
session.use_only_cookies | Off | Off
session.use_trans_sid | On | On

## standard

Regex Library | Bundled library enabled
Dynamic Library Support | enabled
Path to sendmail | /usr/sbin/sendmail -t -i

Directive | Local Value | Master Value
--- | --- | ---
assert.active | 1 | 1
assert.bail | 0 | 0
assert.callback | no value | no value
assert.quiet_eval | 0 | 0
assert.warning | 1 | 1
auto_detect_line_endings | 0 | 0
default_socket_timeout | 60 | 60
safe_mode_allowed_env_vars | PHP_ | PHP_
safe_mode_protected_env_vars | LD_LIBRARY_PATH,TMPDIR | LD_LIBRARY_PATH,TMPDIR
url_rewriter.tags | a=href,area=href,frame=src,input=src,form=,fieldset= | a=href,area=href,frame=src,input=src,form=,fieldset=
user_agent | no value | no value

## sysvmsg

sysvmsg support | enabled
--- | ---
Revision | $Revision: 1.4.2.5.2.3 $

## tokenizer

Tokenizer Support | enabled

## wddx

WDDX Support | enabled
--- | ---
WDDX Session Serializer | enabled

## xml

XML Support | active
XML Namespace Support | active
EXPAT Version | 1.95.6

## zip

Zip support | enabled

## zlib

ZLib Support | enabled
Compiled Version | 1.1.4
Linked Version | 1.1.4

Directive | Local Value | Master Value
--- | --- | ---
zlib.output_compression | Off | Off
zlib.output_compression_level | -1 | -1
zlib.output_handler | no value | no value

## Additional Modules

Module Name
dbase
ionCube Loader
sysvsem
sysvshm

## Environment

Variable | Value
--- | ---
USER | root
HOME | /root
LOGNAME | root
PATH | /etc:/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin
SHELL | /bin/sh

## PHP License

This program is free software; you can redistribute it and/or modify it under the terms of the PHP License as published by the PHP Group and included in the distribution in the file: LICENSE This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. If you did not receive a copy of the PHP license, or have any questions about PHP licensing, please contact license@php.net.